<?php
// 配置文件路径
$codesFile = __DIR__ . '/codes.txt';

// 确保文件存在且可写
if (!file_exists($codesFile)) {
    touch($codesFile) or die("错误：无法创建 codes.txt 文件，请检查目录权限。");
}

// 检查文件是否可写
if (!is_writable($codesFile)) {
    die("错误：codes.txt 文件不可写，请修改文件权限。");
}

// 生成随机码
function generateRandomCode() {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $code = '';
    for ($i = 0; $i < 4; $i++) {
        $code .= $characters[rand(0, strlen($characters) - 1)];
    }
    return $code;
}

// 读取现有随机码及时间
function readExistingCodes() {
    global $codesFile;
    $existingCodes = [];
    
    if (file_exists($codesFile) && filesize($codesFile) > 0) {
        $content = file_get_contents($codesFile);
        if ($content !== false) {
            $lines = explode("\n", trim($content));
            
            foreach ($lines as $line) {
                if (!empty($line)) {
                    list($code, $datetime) = explode('|', $line);
                    $existingCodes[] = [
                        'code' => $code,
                        'datetime' => $datetime,
                        'timestamp' => strtotime($datetime) // 转换为时间戳用于排序
                    ];
                }
            }
        }
    }
    
    return $existingCodes;
}

// 确保随机码唯一
function getUniqueCode(&$existingCodes) {
    $attempts = 0;
    $maxAttempts = 100;
    
    // 提取已有的随机码
    $existingCodeValues = array_column($existingCodes, 'code');
    
    do {
        if ($attempts >= $maxAttempts) {
            throw new Exception("尝试 $maxAttempts 次后仍无法生成唯一随机码，可能所有组合已用尽");
        }
        
        $code = generateRandomCode();
        $attempts++;
    } while (in_array($code, $existingCodeValues));
    
    return $code;
}

// 保存随机码到文件
function saveCodeToFile($code) {
    global $codesFile;
    
    $datetime = date('Y-m-d H:i:s'); // 直接格式化为可读时间
    $line = "$code|$datetime\n";
    
    // 追加新代码到文件
    $result = file_put_contents($codesFile, $line, FILE_APPEND | LOCK_EX);
    return $result !== false;
}

// 处理生成请求
$newCode = '';
$errorMessage = '';

if (isset($_POST['generate'])) {
    try {
        // 获取已存在的随机码
        $existingCodes = readExistingCodes();
        
        // 生成唯一随机码
        $newCode = getUniqueCode($existingCodes);
        
        // 保存到文件（包含格式化时间）
        if (!saveCodeToFile($newCode)) {
            throw new Exception("无法保存随机码到文件");
        }
    } catch (Exception $e) {
        $errorMessage = $e->getMessage();
    }
}

// 获取最近生成的10个随机码
$recentCodes = [];
if (file_exists($codesFile) && filesize($codesFile) > 0) {
    $existingCodes = readExistingCodes();
    
    // 按时间戳排序（最新的在前）
    usort($existingCodes, function($a, $b) {
        return $b['timestamp'] - $a['timestamp'];
    });
    
    $recentCodes = array_slice($existingCodes, 0, 10);
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>随机码生成器</title>
    <style>
        /* 基础样式 */
        * {
            box-sizing: border-box;
            margin: 0;
            padding: 0;
            font-family: Arial, sans-serif;
        }
        
        body {
            background: linear-gradient(135deg, #f5f7fa 0%, #e4ecfa 100%);
            min-height: 100vh;
            display: flex;
            flex-direction: column;
        }
        
        /* 导航栏 */
        .navbar {
            background-color: white;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
            padding: 16px 24px;
            position: fixed;
            width: 100%;
            z-index: 100;
            transition: all 0.3s ease;
        }
        
        .navbar.scrolled {
            background-color: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(5px);
        }
        
        .navbar-content {
            max-width: 1200px;
            margin: 0 auto;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        
        .logo {
            color: #3B82F6;
            font-size: 24px;
            font-weight: bold;
            display: flex;
            align-items: center;
        }
        
        .logo i {
            margin-right: 8px;
        }
        
        .stats {
            color: #64748B;
            font-size: 14px;
        }
        
        /* 主内容 */
        .main-content {
            flex-grow: 1;
            max-width: 1200px;
            margin: 0 auto;
            padding: 80px 24px 40px;
            width: 100%;
        }
        
        .error-message {
            background-color: #FEE2E2;
            color: #EF4444;
            padding: 12px;
            border-radius: 8px;
            margin-bottom: 24px;
            font-weight: bold;
            max-width: 800px;
            margin-left: auto;
            margin-right: auto;
        }
        
        .title-section {
            text-align: center;
            margin-bottom: 40px;
        }
        
        .title-section h1 {
            font-size: clamp(1.8rem, 5vw, 2.8rem);
            font-weight: bold;
            color: #1E293B;
            margin-bottom: 16px;
            text-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }
        
        .title-section p {
            color: #64748B;
            max-width: 800px;
            margin: 0 auto;
        }
        
        /* 随机码显示卡片 */
        .code-card {
            background-color: white;
            border-radius: 16px;
            box-shadow: 0 10px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
            padding: 32px;
            max-width: 400px;
            margin: 0 auto 40px;
            transition: all 0.3s ease;
        }
        
        .code-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 20px 30px -10px rgba(0, 0, 0, 0.15);
        }
        
        .code-card h2 {
            font-size: 20px;
            font-weight: bold;
            text-align: center;
            margin-bottom: 24px;
            color: #334155;
        }
        
        .code-display {
            background: linear-gradient(135deg, #e0f2fe 0%, #e0e7ff 100%);
            border-radius: 12px;
            padding: 24px;
            text-align: center;
            margin-bottom: 24px;
            border: 1px solid #cbd5e1;
        }
        
        .code-value {
            font-size: 48px;
            font-weight: bold;
            background: linear-gradient(90deg, #3B82F6, #6366F1);
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
        }
        
        .empty-code {
            font-size: 48px;
            font-weight: bold;
            color: #94A3B8;
        }
        
        .generate-button {
            background: linear-gradient(135deg, #3B82F6 0%, #6366F1 100%);
            color: white;
            font-weight: bold;
            padding: 16px 24px;
            border-radius: 12px;
            border: none;
            cursor: pointer;
            width: 100%;
            transition: all 0.3s ease;
            font-size: 16px;
            display: flex;
            justify-content: center;
            align-items: center;
        }
        
        .generate-button:hover {
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
            transform: translateY(-2px);
        }
        
        .generate-button:active {
            transform: translateY(1px);
        }
        
        /* 最近生成的随机码 */
        .recent-codes {
            background-color: white;
            border-radius: 16px;
            box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
            padding: 24px;
            margin-bottom: 32px;
        }
        
        .section-title {
            font-size: 20px;
            font-weight: bold;
            color: #334155;
            margin-bottom: 16px;
            display: flex;
            align-items: center;
        }
        
        .section-title::before {
            content: "•";
            color: #3B82F6;
            margin-right: 8px;
        }
        
        .table-container {
            overflow-x: auto;
        }
        
        .code-table {
            width: 100%;
            border-collapse: collapse;
        }
        
        .code-table th, .code-table td {
            padding: 12px 16px;
            text-align: left;
            border-bottom: 1px solid #e2e8f0;
        }
        
        .code-table th {
            background-color: #f8fafc;
            color: #64748B;
            font-size: 14px;
            text-transform: uppercase;
        }
        
        .code-table tr:hover {
            background-color: #f1f5f9;
        }
        
        /* 统计信息 */
        .stats-container {
            display: grid;
            grid-template-columns: 1fr;
            gap: 24px;
        }
        
        @media (min-width: 768px) {
            .stats-container {
                grid-template-columns: 1fr 1fr 1fr;
            }
        }
        
        .stat-card {
            background-color: white;
            border-radius: 12px;
            box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
            padding: 24px;
            display: flex;
            align-items: center;
            transition: all 0.3s ease;
        }
        
        .stat-card:hover {
            transform: translateY(-3px);
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1);
        }
        
        .stat-icon {
            width: 48px;
            height: 48px;
            border-radius: 50%;
            background-color: #e0f2fe;
            display: flex;
            align-items: center;
            justify-content: center;
            color: #3B82F6;
            margin-right: 16px;
        }
        
        .stat-value {
            font-size: 24px;
            font-weight: bold;
            color: #1E293B;
        }
        
        .stat-label {
            font-size: 14px;
            color: #64748B;
        }
        
        /* 页脚 */
        footer {
            background-color: #1E293B;
            color: #94A3B8;
            text-align: center;
            padding: 24px 0;
            font-size: 14px;
        }
        
        /* 提示消息 */
        .toast {
            position: fixed;
            bottom: 20px;
            right: 20px;
            background-color: #1E293B;
            color: white;
            padding: 12px 24px;
            border-radius: 8px;
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
            opacity: 0;
            transform: translateY(20px);
            transition: all 0.3s ease;
            z-index: 1000;
            display: flex;
            align-items: center;
        }
        
        .toast.show {
            opacity: 1;
            transform: translateY(0);
        }
        
        .toast i {
            margin-right: 8px;
        }
    </style>
</head>
<body>
    <!-- 导航栏 -->
    <nav class="navbar" id="navbar">
        <div class="navbar-content">
            <div class="logo">
                <i class="fa fa-random"></i>随机码生成器
            </div>
            <div class="stats">
                <i class="fa fa-database"></i>已生成: <?php echo count($existingCodes); ?>
            </div>
        </div>
    </nav>

    <!-- 主内容 -->
    <main class="main-content">
        <?php if ($errorMessage) : ?>
            <div class="error-message">
                <?php echo $errorMessage; ?>
            </div>
        <?php endif; ?>

        <div class="title-section">
            <h1>四位数随机码生成器</h1>
            <p>生成唯一的四位数随机码（数字+英文），所有生成的随机码都会被保存，确保不会重复</p>
        </div>

        <!-- 随机码显示卡片 -->
        <div class="code-card">
            <h2>当前生成的随机码</h2>
            <div class="code-display" id="code-display">
                <?php if ($newCode) : ?>
                    <span class="code-value"><?php echo $newCode; ?></span>
                <?php else : ?>
                    <span class="empty-code">点击下方按钮生成</span>
                <?php endif; ?>
            </div>
            <form method="post">
                <button type="submit" name="generate" class="generate-button">
                    <i class="fa fa-refresh mr-2"></i>
                    <span>生成随机码</span>
                </button>
            </form>
        </div>

        <!-- 最近生成的随机码 -->
        <div class="recent-codes">
            <div class="section-title">
                <i class="fa fa-history"></i>最近生成的随机码
            </div>
            <div class="table-container">
                <table class="code-table">
                    <thead>
                        <tr>
                            <th>序号</th>
                            <th>随机码</th>
                            <th>生成时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recentCodes as $index => $record) : ?>
                            <tr>
                                <td><?php echo $index + 1; ?></td>
                                <td><?php echo $record['code']; ?></td>
                                <td><?php echo $record['datetime']; ?></td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($recentCodes)) : ?>
                            <tr>
                                <td colspan="3" style="text-align: center; color: #64748B;">暂无生成记录</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- 统计信息 -->
        <div class="stats-container">
            <div class="stat-card">
                <div class="stat-icon">
                    <i class="fa fa-database"></i>
                </div>
                <div>
                    <div class="stat-label">总生成数量</div>
                    <div class="stat-value"><?php echo count($existingCodes); ?></div>
                </div>
            </div>

            <div class="stat-card">
                <div class="stat-icon">
                    <i class="fa fa-clock-o"></i>
                </div>
                <div>
                    <div class="stat-label">上次更新</div>
                    <div class="stat-value">
                        <?php echo !empty($existingCodes) ? $existingCodes[0]['datetime'] : '从未更新'; ?>
                    </div>
                </div>
            </div>

            <div class="stat-card">
                <div class="stat-icon">
                    <i class="fa fa-calculator"></i>
                </div>
                <div>
                    <div class="stat-label">可用组合</div>
                    <div class="stat-value">
                        <?php echo number_format(62**4 - count($existingCodes)); ?>
                    </div>
                </div>
            </div>
        </div>
    </main>

    <!-- 页脚 -->
    <footer>
        <div class="container">
            <p>© 2025 随机码生成器. 保留所有权利.</p>
        </div>
    </footer>

    <!-- 提示消息 -->
    <div id="toast" class="toast"></div>

    <script>
        // 导航栏滚动效果
        window.addEventListener('scroll', function() {
            const navbar = document.getElementById('navbar');
            if (window.scrollY > 10) {
                navbar.classList.add('scrolled');
            } else {
                navbar.classList.remove('scrolled');
            }
        });

        // 复制功能
        document.addEventListener('DOMContentLoaded', function() {
            const codeDisplay = document.getElementById('code-display');
            if (codeDisplay && codeDisplay.textContent.trim() !== '点击下方按钮生成') {
                codeDisplay.addEventListener('click', function() {
                    const code = this.textContent.trim();
                    navigator.clipboard.writeText(code).then(() => {
                        showToast('随机码已复制到剪贴板');
                    });
                });
            }
        });

        // 显示提示消息
        function showToast(message) {
            const toast = document.getElementById('toast');
            toast.innerHTML = '<i class="fa fa-check-circle"></i>' + message;
            toast.classList.add('show');
            
            setTimeout(() => {
                toast.classList.remove('show');
            }, 3000);
        }
    </script>
</body>
</html>